@@ -1,6 +1,6 @@
 #' @rdname import
 #' @title Import
-#' @description Read in a data.frame from a file
+#' @description Read in a data.frame from a file. Exceptions to this rule are Rdata, RDS, and JSON input file formats, which return the originally saved object without changing its class.
 #' @param file A character string naming a file, URL, or single-file .zip or .tar archive.
 #' @param format An optional character string code of file format, which can be used to override the format inferred from \code{file}. Shortcuts include: \dQuote{,} (for comma-separated values), \dQuote{;} (for semicolon-separated values), and \dQuote{|} (for pipe-separated values).
 #' @template setclass
@@ -18,13 +18,13 @@
 #'     \item SAS (.sas7bdat), using \code{\link[haven]{read_sas}}.
 #'     \item SAS XPORT (.xpt), using \code{\link[haven]{read_xpt}} or, if \code{haven = FALSE}, \code{\link[foreign]{read.xport}}.
 #'     \item SPSS (.sav), using \code{\link[haven]{read_sav}}. If \code{haven = FALSE}, \code{\link[foreign]{read.spss}} can be used.
+#'     \item SPSS compressed (.zsav), using \code{\link[haven]{read_sav}}.
 #'     \item Stata (.dta), using \code{\link[haven]{read_dta}}. If \code{haven = FALSE}, \code{\link[foreign]{read.dta}} can be used.
-#'     \item SAS XPORT (.xpt), using \code{\link[foreign]{read.xport}}.
 #'     \item SPSS Portable Files (.por), using \code{\link[haven]{read_por}}.
 #'     \item Excel (.xls and .xlsx), using \code{\link[readxl]{read_excel}}. Use \code{which} to specify a sheet number. For .xlsx files, it is possible to set \code{readxl = FALSE}, so that \code{\link[openxlsx]{read.xlsx}} can be used instead of readxl (the default).
 #'     \item R syntax object (.R), using \code{\link[base]{dget}}
-#'     \item Saved R objects (.RData,.rda), using \code{\link[base]{load}} for single-object .Rdata files. Use \code{which} to specify an object name for multi-object .Rdata files.
-#'     \item Serialized R objects (.rds), using \code{\link[base]{readRDS}}
+#'     \item Saved R objects (.RData,.rda), using \code{\link[base]{load}} for single-object .Rdata files. Use \code{which} to specify an object name for multi-object .Rdata files. This can be any R object (not just a data frame).
+#'     \item Serialized R objects (.rds), using \code{\link[base]{readRDS}}. This can be any R object (not just a data frame).
 #'     \item Epiinfo (.rec), using \code{\link[foreign]{read.epiinfo}}
 #'     \item Minitab (.mtp), using \code{\link[foreign]{read.mtp}}
 #'     \item Systat (.syd), using \code{\link[foreign]{read.systat}}
@@ -34,17 +34,20 @@
 #'     \item Fortran data (no recognized extension), using \code{\link[utils]{read.fortran}}
 #'     \item Fixed-width format data (.fwf), using a faster version of \code{\link[utils]{read.fwf}} that requires a \code{widths} argument and by default in rio has \code{stringsAsFactors = FALSE}. If \code{readr = TRUE}, import will be performed using \code{\link[readr]{read_fwf}}, where \code{widths} should be: \code{NULL}, a vector of column widths, or the output of \code{\link[readr]{fwf_empty}}, \code{\link[readr]{fwf_widths}}, or \code{\link[readr]{fwf_positions}}.
 #'     \item gzip comma-separated data (.csv.gz), using \code{\link[utils]{read.table}} with \code{row.names = FALSE} and \code{stringsAsFactors = FALSE}
-#'     \item \href{https://github.com/csvy}{CSVY} (CSV with a YAML metadata header) using \code{\link[csvy]{read_csvy}}.
+#'     \item \href{https://github.com/csvy}{CSVY} (CSV with a YAML metadata header) using \code{\link[data.table]{fread}}.
+#'     \item Apache Arrow Parquet (.parquet), using \code{\link[arrow]{read_parquet}}
 #'     \item Feather R/Python interchange format (.feather), using \code{\link[feather]{read_feather}}
 #'     \item Fast storage (.fst), using \code{\link[fst]{read.fst}}
 #'     \item JSON (.json), using \code{\link[jsonlite]{fromJSON}}
 #'     \item Matlab (.mat), using \code{\link[rmatio]{read.mat}}
+#'     \item EViews (.wf1), using \code{\link[hexView]{readEViews}}
 #'     \item OpenDocument Spreadsheet (.ods), using \code{\link[readODS]{read_ods}}.  Use \code{which} to specify a sheet number.
 #'     \item Single-table HTML documents (.html), using \code{\link[xml2]{read_html}}. The data structure will only be read correctly if the HTML file can be converted to a list via \code{\link[xml2]{as_list}}.
 #'     \item Shallow XML documents (.xml), using \code{\link[xml2]{read_xml}}. The data structure will only be read correctly if the XML file can be converted to a list via \code{\link[xml2]{as_list}}.
 #'     \item YAML (.yml), using \code{\link[yaml]{yaml.load}}
 #'     \item Clipboard import (on Windows and Mac OS), using \code{\link[utils]{read.table}} with \code{row.names = FALSE}
 #'     \item Google Sheets, as Comma-separated data (.csv)
+#'     \item GraphPad Prism (.pzfx) using \code{\link[pzfx]{read_pzfx}}
 #' }
 #'
 #' \code{import} attempts to standardize the return value from the various import functions to the extent possible, thus providing a uniform data structure regardless of what import package or function is used. It achieves this by storing any optional variable-related attributes at the variable level (i.e., an attribute for \code{mtcars$mpg} is stored in \code{attributes(mtcars$mpg)} rather than \code{attributes(mtcars)}). If you would prefer these attributes to be stored at the data.frame-level (i.e., in \code{attributes(mtcars)}), see \code{\link{gather_attrs}}.
@@ -62,7 +65,6 @@
 #'
 #' # import CSV as a `data.table`
 #' stopifnot(inherits(import("iris1.csv", setclass = "data.table"), "data.table"))
-#' stopifnot(inherits(import("iris1.csv", setclass = "data.table"), "data.table"))
 #'
 #' # pass arguments to underlying import function
 #' iris1 <- import("iris1.csv")
@@ -74,11 +76,17 @@
 #'
 #' # set class for the response data.frame as "tbl_df" (from dplyr)
 #' stopifnot(inherits(import("iris1.csv", setclass = "tbl_df"), "tbl_df"))
+#' 
+#' # non-data frame formats supported for RDS, Rdata, and JSON
+#' export(list(mtcars, iris), "list.rds")
+#' li <- import("list.rds")
+#' identical(names(mtcars), names(li[[1]]))
 #'
 #' # cleanup
 #' unlink("iris.tsv")
 #' unlink("iris1.csv")
 #' unlink("iris2.csv")
+#' unlink("list.rds")
 #'
 #' @seealso \code{\link{import_list}}, \code{\link{.import}}, \code{\link{characterize}}, \code{\link{gather_attrs}}, \code{\link{export}}, \code{\link{convert}}
 #' @importFrom tools file_ext file_path_sans_ext
@@ -110,29 +118,37 @@ import <- function(file, format, setclass, which, ...) {
     if (missing(format)) {
         fmt <- get_ext(file)
         if (fmt %in% c("gz", "gzip")) {
-            fmt <- file_ext(file_path_sans_ext(file, compression = FALSE))
+            fmt <- tools::file_ext(tools::file_path_sans_ext(file, compression = FALSE))
             file <- gzfile(file)
+        } else {
+            fmt <- get_type(fmt)
         }
     } else {
         fmt <- get_type(format)
     }
-
+    
+    args_list <- list(...)
+    
     class(file) <- c(paste0("rio_", fmt), class(file))
     if (missing(which)) {
         x <- .import(file = file, ...)
     } else {
         x <- .import(file = file, which = which, ...)
     }
-
-    a <- list(...)
+    
+    # if R serialized object, just return it without setting object class
+    if (inherits(file, c("rio_rdata", "rio_rds", "rio_json"))) {
+        return(x)
+    }
+    # otherwise, make sure it's a data frame (or requested class)
     if (missing(setclass) || is.null(setclass)) {
-        if ("data.table" %in% names(a) && isTRUE(a[["data.table"]])) {
+        if ("data.table" %in% names(args_list) && isTRUE(args_list[["data.table"]])) {
             return(set_class(x, class = "data.table"))
         } else {
             return(set_class(x, class = "data.frame"))
         }
     } else {
-        if ("data.table" %in% names(a) && isTRUE(a[["data.table"]])) {
+        if ("data.table" %in% names(args_list) && isTRUE(args_list[["data.table"]])) {
             if (setclass != "data.table") {
                 warning(sprintf("'data.table = TRUE' argument overruled. Using setclass = '%s'", setclass))
                 return(set_class(x, class = setclass))
@@ -143,5 +159,4 @@ import <- function(file, format, setclass, which, ...) {
             return(set_class(x, class = setclass))
         }
     }
-
 }
